===
API
===

.. currentmodule:: coiled.analytics

.. autosummary::
   coiled.analytics.register
   coiled.analytics.list_clusters
   coiled.analytics.list_computations
   coiled.analytics.list_events

.. autofunction:: coiled.analytics.register
.. autofunction:: coiled.analytics.list_clusters
.. autofunction:: coiled.analytics.list_computations
.. autofunction:: coiled.analytics.list_events
